==> cms-db_v0.7.9.tar.gz: admin/locale.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('locale');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button'])) {
			$writethis = '<?php
			$locale_default = "'.$_POST["locale_default"].'";
			?>';
			$datei = fopen('../data/settings/locale.inc.php','w');
			fwrite($datei,$writethis);
			fclose($datei);
			echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
		}
		include('../data/settings/locale.inc.php');
		?>

		<h2><?php locale('title') ?></h2>
		<p>
			<form action="locale.php?<?php echo SID ?>" method="post">
				<?php locale('label_locale') ?>
				<select name="locale_default" size="1">
					<?php
					if ($handle = opendir('./locales')) {
						while (false !== ($file = readdir($handle))) {
							if(is_file('./locales/'.$file.'/info.php')) {
								include('./locales/'.$file.'/info.php');
								if ($file == $locale_default) {
									echo '<option value="'.$file.'" selected="selected">'.$locale_info["name"].'</option>';
								} else {
									echo '<option value="'.$file.'">'.$locale_info["name"].'</option>';
								}
							}
						}
						closedir($handle);
					}
					?>
				</select>
				<br />
				<input type="submit" name="button" value="<?php locale('button_save') ?>"><?php echo $saved ?>
			</form>
		</p>

	</body>
</html>

==> cms-db_v0.7.11.tar.gz: admin/locale.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('locale');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="ftpsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_ftpsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button'])) {
			$writethis = '<?php
			$locale_default = \''.$_POST['locale_default'].'\';
			?>';
			file_put_contents('../data/settings/locale.inc.php', $writethis);
			echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
		}
		include('../data/settings/locale.inc.php');
		?>

		<h2><?php locale('title') ?></h2>
		<p>
			<form action="locale.php?<?php echo SID ?>" method="post">
				<?php locale('label_locale') ?>
				<select name="locale_default" size="1">
					<?php
					if ($handle = opendir('./locales')) {
						while (false !== ($file = readdir($handle))) {
							if(is_file('./locales/'.$file.'/info.php')) {
								include('./locales/'.$file.'/info.php');
								if ($file == $locale_default) {
									echo '<option value="'.$file.'" selected="selected">'.$locale_info['name'].'</option>';
								} else {
									echo '<option value="'.$file.'">'.$locale_info['name'].'</option>';
								}
							}
						}
						closedir($handle);
					}
					?>
				</select>
				<br />
				<input type="submit" name="button" value="<?php locale('button_save') ?>"><?php echo $saved ?>
			</form>
		</p>

	</body>
</html>
